@@ -1,7 +1,5 @@
-# encoding: utf-8
-
 $LOAD_PATH.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))
-require "prawn"
+require 'prawn'
 
 GC.disable
 
@@ -15,4 +13,3 @@ after = GC.stat
 total = after[:total_allocated_object] - before[:total_allocated_object]
 
 puts "allocated objects: #{total}"
-
