@@ -1,15 +1,14 @@
-# encoding: utf-8
-#
 # font.rb : The Prawn font class
 #
 # Copyright May 2008, Gregory Brown / James Healy. All Rights Reserved.
 #
 # This is free software. Please see the LICENSE and COPYING files for details.
 #
-require_relative "font/afm"
-require_relative "font/ttf"
-require_relative "font/dfont"
-require_relative "font_metric_cache"
+require_relative 'font/afm'
+require_relative 'font/ttf'
+require_relative 'font/dfont'
+require_relative 'font/ttc'
+require_relative 'font_metric_cache'
 
 module Prawn
   class Document
@@ -35,8 +34,8 @@ module Prawn
     #   end
     #
     # The :name parameter must be a string. It can be one of the 14 built-in
-    # fonts supported by PDF, or the location of a TTF file. The Font::AFM::BUILT_INS
-    # array specifies the valid built in font values.
+    # fonts supported by PDF, or the location of a TTF file. The
+    # Font::AFM::BUILT_INS array specifies the valid built in font values.
     #
     # If a ttf font is specified, the glyphs necessary to render your document
     # will be embedded in the rendered PDF. This should be your preferred option
@@ -44,14 +43,15 @@ module Prawn
     # make it more portable.
     #
     # The options parameter is an optional hash providing size and style. To use
-    # the :style option you need to map those font styles to their respective font files.
+    # the :style option you need to map those font styles to their respective
+    # font files.
     # See font_families for more information.
     #
     def font(name = nil, options = {})
-      return((defined?(@font) && @font) || font("Helvetica")) if name.nil?
+      return((defined?(@font) && @font) || font('Helvetica')) if name.nil?
 
       if state.pages.empty? && !state.page.in_stamp_stream?
-        fail Prawn::Errors::NotOnPage
+        raise Prawn::Errors::NotOnPage
       end
 
       new_font = find_font(name.to_s, options)
@@ -107,33 +107,35 @@ module Prawn
       font_size(size)
     end
 
-    # Returns the width of the given string using the given font. If :size is not
-    # specified as one of the options, the string is measured using the current
-    # font size. You can also pass :kerning as an option to indicate whether
-    # kerning should be used when measuring the width (defaults to +false+).
+    # Returns the width of the given string using the given font. If :size is
+    # not specified as one of the options, the string is measured using the
+    # current font size. You can also pass :kerning as an option to indicate
+    # whether kerning should be used when measuring the width (defaults to
+    # +false+).
     #
     # Note that the string _must_ be encoded properly for the font being used.
     # For AFM fonts, this is WinAnsi. For TTF, make sure the font is encoded as
     # UTF-8. You can use the Font#normalize_encoding method to make sure strings
     # are in an encoding appropriate for the current font.
     #--
-    # For the record, this method used to be a method of Font (and still delegates
-    # to width computations on Font). However, having the primary interface for
-    # calculating string widths exist on Font made it tricky to write extensions
-    # for Prawn in which widths are computed differently (e.g., taking formatting
-    # tags into account, or the like).
+    # For the record, this method used to be a method of Font (and still
+    # delegates to width computations on Font). However, having the primary
+    # interface for calculating string widths exist on Font made it tricky to
+    # write extensions for Prawn in which widths are computed differently (e.g.,
+    # taking formatting tags into account, or the like).
     #
-    # By putting width_of here, on Document itself, extensions may easily override
-    # it and redefine the width calculation behavior.
+    # By putting width_of here, on Document itself, extensions may easily
+    # override it and redefine the width calculation behavior.
     #++
     def width_of(string, options = {})
-      if p = options[:inline_format]
+      if options.key? :inline_format
+        p = options[:inline_format]
         p = [] unless p.is_a?(Array)
 
         # Build up an Arranger with the entire string on one line, finalize it,
         # and find its width.
         arranger = Prawn::Text::Formatted::Arranger.new(self, options)
-        arranger.consumed = self.text_formatter.format(string, *p)
+        arranger.consumed = text_formatter.format(string, *p)
         arranger.finalize_line
 
         arranger.line_width
@@ -169,20 +171,26 @@ module Prawn
     #
     def font_families
       @font_families ||= {}.merge!(
-        "Courier"     => { :bold        => "Courier-Bold",
-                           :italic      => "Courier-Oblique",
-                           :bold_italic => "Courier-BoldOblique",
-                           :normal      => "Courier" },
+        'Courier' => {
+          bold: 'Courier-Bold',
+          italic: 'Courier-Oblique',
+          bold_italic: 'Courier-BoldOblique',
+          normal: 'Courier'
+        },
 
-        "Times-Roman" => { :bold         => "Times-Bold",
-                           :italic       => "Times-Italic",
-                           :bold_italic  => "Times-BoldItalic",
-                           :normal       => "Times-Roman" },
+        'Times-Roman' => {
+          bold: 'Times-Bold',
+          italic: 'Times-Italic',
+          bold_italic: 'Times-BoldItalic',
+          normal: 'Times-Roman'
+        },
 
-        "Helvetica"   => { :bold         => "Helvetica-Bold",
-                           :italic       => "Helvetica-Oblique",
-                           :bold_italic  => "Helvetica-BoldOblique",
-                           :normal       => "Helvetica" }
+        'Helvetica' => {
+          bold: 'Helvetica-Bold',
+          italic: 'Helvetica-Oblique',
+          bold_italic: 'Helvetica-BoldOblique',
+          normal: 'Helvetica'
+        }
       )
     end
 
@@ -200,7 +208,7 @@ module Prawn
     # finishes, the original font is restored.
     #
     def save_font
-      @font ||= find_font("Helvetica")
+      @font ||= find_font('Helvetica')
       original_font = @font
       original_size = @font_size
 
@@ -210,26 +218,27 @@ module Prawn
     end
 
     # Looks up the given font using the given criteria. Once a font has been
-    # found by that matches the criteria, it will be cached to subsequent lookups
-    # for that font will return the same object.
-    #--
+    # found by that matches the criteria, it will be cached to subsequent
+    # lookups for that font will return the same object.
+    # --
     # Challenges involved: the name alone is not sufficient to uniquely identify
     # a font (think dfont suitcases that can hold multiple different fonts in a
     # single file). Thus, the :name key is included in the cache key.
     #
     # It is further complicated, however, since fonts in some formats (like the
     # dfont suitcases) can be identified either by numeric index, OR by their
-    # name within the suitcase, and both should hash to the same font object
-    # (to avoid the font being embedded multiple times). This is not yet implemented,
-    # which means if someone selects a font both by name, and by index, the
-    # font will be embedded twice. Since we do font subsetting, this double
-    # embedding won't be catastrophic, just annoying.
+    # name within the suitcase, and both should hash to the same font object (to
+    # avoid the font being embedded multiple times). This is not yet
+    # implemented, which means if someone selects a font both by name, and by
+    # index, the font will be embedded twice. Since we do font subsetting, this
+    # double embedding won't be catastrophic, just annoying.
     # ++
     #
     # @private
     def find_font(name, options = {}) #:nodoc:
       if font_families.key?(name)
-        family, name = name, font_families[name][options[:style] || :normal]
+        family = name
+        name = font_families[name][options[:style] || :normal]
         if name.is_a?(::Hash)
           options = options.merge(name)
           name = options[:file]
@@ -240,7 +249,8 @@ module Prawn
       if name.is_a? Prawn::Font
         font_registry[key] = name
       else
-        font_registry[key] ||= Font.load(self, name, options.merge(family: family))
+        font_registry[key] ||=
+          Font.load(self, name, options.merge(family: family))
       end
     end
 
@@ -280,12 +290,14 @@ module Prawn
     attr_reader :options
 
     # Shortcut interface for constructing a font object.  Filenames of the form
-    # *.ttf will call Font::TTF.new, *.dfont Font::DFont.new, and anything else
-    # will be passed through to Font::AFM.new()
+    # *.ttf will call Font::TTF.new, *.dfont Font::DFont.new, *.ttc goes to
+    # Font::TTC.new, and anything else will be passed through to
+    # Font::AFM.new()
     def self.load(document, src, options = {})
       case font_format(src, options)
       when 'ttf'   then TTF.new(document, src, options)
       when 'dfont' then DFont.new(document, src, options)
+      when 'ttc'   then TTC.new(document, src, options)
       else AFM.new(document, src, options)
       end
     end
@@ -296,16 +308,17 @@ module Prawn
       case src.to_s
       when /\.ttf$/i   then return 'ttf'
       when /\.dfont$/i then return 'dfont'
+      when /\.ttc$/i   then return 'ttc'
       else return 'afm'
       end
     end
 
     def initialize(document, name, options = {}) #:nodoc:
-      @document   = document
-      @name       = name
-      @options    = options
+      @document = document
+      @name = name
+      @options = options
 
-      @family     = options[:family]
+      @family = options[:family]
 
       @identifier = generate_unique_id
 
@@ -334,8 +347,9 @@ module Prawn
     # font. The string is expected to be UTF-8 going in. It will be re-encoded
     # and the new string will be returned. For an in-place (destructive)
     # version, see normalize_encoding!.
-    def normalize_encoding(string)
-      fail NotImplementedError, "subclasses of Prawn::Font must implement #normalize_encoding"
+    def normalize_encoding(_string)
+      raise NotImplementedError,
+        'subclasses of Prawn::Font must implement #normalize_encoding'
     end
 
     # Destructive version of normalize_encoding; normalizes the encoding of a
@@ -364,7 +378,9 @@ module Prawn
     #
     def add_to_current_page(subset)
       @references[subset] ||= register(subset)
-      @document.state.page.fonts.merge!(identifier_for(subset) => @references[subset])
+      @document.state.page.fonts.merge!(
+        identifier_for(subset) => @references[subset]
+      )
     end
 
     def identifier_for(subset) #:nodoc:
@@ -381,14 +397,14 @@ module Prawn
     # Prawn::Table::Text#styled_with_of_single_character)
     #
     def hash #:nodoc:
-      [ self.class, self.name, self.family, size ].hash
+      [self.class, name, family, size].hash
     end
 
     # Compliments the #hash implementation above
     #
     def eql?(other) #:nodoc:
-      self.class == other.class && self.name == other.name &&
-        self.family == other.family && size == other.send(:size)
+      self.class == other.class && name == other.name &&
+        family == other.family && size == other.send(:size)
     end
 
     private
