@@ -1,5 +1,3 @@
-# encoding: utf-8
-#
 # font_metric_cache.rb : The Prawn font class
 #
 # Copyright Dec 2012, Kenneth Kalmer. All Rights Reserved.
@@ -24,19 +22,22 @@ module Prawn
     def width_of(string, options)
       f = if options[:style]
             # override style with :style => :bold
-            @document.find_font(@document.font.family, :style => options[:style])
+            @document.find_font(@document.font.family, style: options[:style])
           else
             @document.font
           end
 
-      key = CacheEntry.new(f, options, string)
+      encoded_string = f.normalize_encoding(string)
 
-      unless length = @cache[ key ]
-        length = @cache[ key ] = f.compute_width_of(string, options)
-      end
+      key = CacheEntry.new(f, options, encoded_string)
+
+      @cache[key] ||= f.compute_width_of(encoded_string, options)
+
+      length = @cache[key]
 
       length +
-        (@document.character_spacing * @document.font.character_count(string))
+        (@document.character_spacing *
+         @document.font.character_count(encoded_string))
     end
   end
 end
