@@ -1,5 +1,3 @@
-# encoding: utf-8
-
 # ImageHandler provides a way to register image processors with Prawn
 #
 # Contributed by Evan Sharp in November 2013.
@@ -29,16 +27,16 @@ module Prawn
     end
 
     def unregister(handler)
-      @handlers.reject!{ |h| h == handler }
+      @handlers.reject! { |h| h == handler }
     end
 
     def find(image_blob)
-      handler = @handlers.find{ |h| h.can_render? image_blob }
+      handler = @handlers.find { |h| h.can_render? image_blob }
 
       return handler if handler
 
-      fail Prawn::Errors::UnsupportedImageType,
-           "image file is an unrecognised format"
+      raise Prawn::Errors::UnsupportedImageType,
+        'image file is an unrecognised format'
     end
   end
 end
