@@ -1,4 +1,3 @@
-# encoding: utf-8
 # measurement_extensions.rb: Core extensions for Prawn::Measurements
 #
 # Copyright December 2008, Florian Witteler.  All Rights Reserved.
@@ -17,34 +16,34 @@ class Numeric
   # @group Experimental API
 
   def mm
-    return mm2pt(self)
+    mm2pt(self)
   end
 
   def cm
-    return cm2pt(self)
+    cm2pt(self)
   end
 
   def dm
-    return dm2pt(self)
+    dm2pt(self)
   end
 
   def m
-    return m2pt(self)
+    m2pt(self)
   end
 
   def in
-    return in2pt(self)
+    in2pt(self)
   end
 
   def yd
-    return yd2pt(self)
+    yd2pt(self)
   end
 
   def ft
-    return ft2pt(self)
+    ft2pt(self)
   end
 
   def pt
-    return pt2pt(self)
+    pt2pt(self)
   end
 end
