@@ -1,5 +1,3 @@
-# encoding: utf-8
-#
 # A PDF document is a collection of pages. When we create a new document be it
 # with <code>Document.new</code> or on a <code>Document.generate</code> block
 # one initial page is created for us.
@@ -12,14 +10,13 @@
 #
 # Just use the <code>start_new_page</code> method and a shiny new page will be
 # created for you just like in the following snippet.
-#
-require File.expand_path(File.join(File.dirname(__FILE__),
-                                   %w[.. example_helper]))
+
+require_relative '../example_helper'
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
-  text "We are still on the initial page for this example. Now I'll ask " +
-       "Prawn to gently start a new page. Please follow me to the next page."
+  text "We are still on the initial page for this example. Now I'll ask " \
+    'Prawn to gently start a new page. Please follow me to the next page.'
 
   start_new_page
 
