@@ -1,5 +1,3 @@
-# encoding: utf-8
-#
 # The origin example already mentions that a new document already comes with
 # a margin box whose bottom left corner is used as the origin for calculating
 # coordinates.
@@ -9,9 +7,8 @@
 # box mapped to the absolute coordinates and evaluating the code inside it.
 #
 # The following snippet draws a circle on each of the four absolute corners.
-#
-require File.expand_path(File.join(File.dirname(__FILE__),
-                                   %w[.. example_helper]))
+
+require_relative '../example_helper'
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
