@@ -1,5 +1,3 @@
-# encoding: utf-8
-#
 # Prawn comes with support for most of the common page sizes so you'll only need
 # to provide specific values if your intended format is not supported. To see a
 # list with all supported sizes take a look at PDF::Core::PageGeometry
@@ -11,23 +9,24 @@
 # You may also define the orientation of the page to be either portrait
 # (default) or landscape. Use <code>:page_layout</code> when creating new
 # documents and <code>:layout</code> when starting new pages.
-#
-require File.expand_path(File.join(File.dirname(__FILE__),
-                                   %w[.. example_helper]))
 
-Prawn::Document.generate("page_size.pdf",
-                         :page_size   => "EXECUTIVE",
-                         :page_layout => :landscape
+require_relative '../example_helper'
+
+filename = File.basename(__FILE__).gsub('.rb', '.pdf')
+Prawn::Document.generate(
+  filename,
+  page_size: 'EXECUTIVE',
+  page_layout: :landscape
 ) do
-  text "EXECUTIVE landscape page."
+  text 'EXECUTIVE landscape page.'
 
   custom_size = [275, 326]
 
-  ["A4", "TABLOID", "B7", custom_size ].each do |size|
-    start_new_page(:size => size, :layout => :portrait)
+  ['A4', 'TABLOID', 'B7', custom_size].each do |size|
+    start_new_page(size: size, layout: :portrait)
     text "#{size} portrait page."
 
-    start_new_page(:size => size, :layout => :landscape)
+    start_new_page(size: size, layout: :landscape)
     text "#{size} landscape page."
   end
 end
