@@ -1,5 +1,3 @@
-# encoding: utf-8
-#
 # Prawn supports drawing both lines and curves starting either at the current
 # position, or from a specified starting position.
 #
@@ -14,9 +12,8 @@
 #
 # Both curve methods define a Bezier curve bounded by two aditional points
 # provided as the <code>:bounds</code> param.
-#
-require File.expand_path(File.join(File.dirname(__FILE__),
-                                   %w[.. example_helper]))
+
+require_relative '../example_helper'
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
@@ -29,13 +26,13 @@ Prawn::ManualBuilder::Example.generate(filename) do
     line_to 100, 100
     line_to 0, 100
 
-    curve_to [150, 250], :bounds => [[20, 200], [120, 200]]
-    curve_to [200, 0],   :bounds => [[150, 200], [450, 10]]
+    curve_to [150, 250], bounds: [[20, 200], [120, 200]]
+    curve_to [200, 0],   bounds: [[150, 200], [450, 10]]
   end
 
   # line and curve
   stroke do
-    line [300,200], [400,50]
-    curve [500, 0], [400, 200], :bounds => [[600, 300], [300, 390]]
+    line [300, 200], [400, 50]
+    curve [500, 0], [400, 200], bounds: [[600, 300], [300, 390]]
   end
 end
