@@ -1,5 +1,3 @@
-# encoding: utf-8
-#
 # This transformation is used to rotate the user space. Give it an angle
 # and an <code>:origin</code> point about which to rotate and a block.
 # Everything inside the block will be drawn with the rotated coordinates.
@@ -7,9 +5,8 @@
 # The angle is in degrees.
 #
 # If you omit the <code>:origin</code> option the page origin will be used.
-#
-require File.expand_path(File.join(File.dirname(__FILE__),
-                                   %w[.. example_helper]))
+
+require_relative '../example_helper'
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
@@ -18,9 +15,9 @@ Prawn::ManualBuilder::Example.generate(filename) do
   fill_circle [250, 200], 2
 
   12.times do |i|
-    rotate(i * 30, :origin => [250, 200]) do
+    rotate(i * 30, origin: [250, 200]) do
       stroke_rectangle [350, 225], 100, 50
-      draw_text "Rotated #{i * 30}°", :size => 10, :at => [360, 205]
+      draw_text "Rotated #{i * 30}°", size: 10, at: [360, 205]
     end
   end
 end
