@@ -1,5 +1,3 @@
-# encoding: utf-8
-#
 # The cap style defines how the edge of a line or curve will be drawn. There are
 # three types: <code>:butt</code> (the default), <code>:round</code> and
 # <code>:projecting_square</code>
@@ -11,9 +9,8 @@
 #
 # Just like <code>line_width=</code> the <code>cap_style=</code> method needs an
 # explicit receiver to work.
-#
-require File.expand_path(File.join(File.dirname(__FILE__),
-                                   %w[.. example_helper]))
+
+require_relative '../example_helper'
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
@@ -25,7 +22,7 @@ Prawn::ManualBuilder::Example.generate(filename) do
     self.cap_style = cap
 
     y = 250 - i * 100
-    stroke_horizontal_line 100, 300, :at => y
+    stroke_horizontal_line 100, 300, at: y
     stroke_circle [400, y], 15
   end
 end
