@@ -1,5 +1,3 @@
-# encoding: utf-8
-#
 # We have already seen how to define an outline tree sequentially.
 #
 # If you'd like to add nodes to the middle of an outline tree the
@@ -16,9 +14,8 @@
 #
 # If the parent title provided is the title of a page. The page will be
 # converted into a section to receive the subsection created.
-#
-require File.expand_path(File.join(File.dirname(__FILE__),
-                                   %w[.. example_helper]))
+
+require_relative '../example_helper'
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
@@ -29,33 +26,33 @@ Prawn::ManualBuilder::Example.generate(filename) do
   end
 
   outline.define do
-    section("Section 1", :destination => 1) do
-      page :title => "Page 2", :destination => 2
-      page :title => "Page 3", :destination => 3
+    section('Section 1', destination: 1) do
+      page title: 'Page 2', destination: 2
+      page title: 'Page 3', destination: 3
     end
   end
 
   # Now we will start adding nodes to the previous outline
-  outline.add_subsection_to("Section 1", :first) do
-    outline.section("Added later - first position") do
-      outline.page :title => "Page 4", :destination => 4
-      outline.page :title => "Page 5", :destination => 5
+  outline.add_subsection_to('Section 1', :first) do
+    outline.section('Added later - first position') do
+      outline.page title: 'Page 4', destination: 4
+      outline.page title: 'Page 5', destination: 5
     end
   end
 
-  outline.add_subsection_to("Section 1") do
-    outline.page :title => "Added later - last position",
-                 :destination => 6
+  outline.add_subsection_to('Section 1') do
+    outline.page title: 'Added later - last position',
+                 destination: 6
   end
 
-  outline.add_subsection_to("Added later - first position") do
-    outline.page :title => "Another page added later",
-                 :destination => 7
+  outline.add_subsection_to('Added later - first position') do
+    outline.page title: 'Another page added later',
+                 destination: 7
   end
 
   # The title provided is for a page which will be converted into a section
-  outline.add_subsection_to("Page 3") do
-    outline.page :title => "Last page added",
-                 :destination => 8
+  outline.add_subsection_to('Page 3') do
+    outline.page title: 'Last page added',
+                 destination: 8
   end
 end
