@@ -1,5 +1,3 @@
-# encoding: utf-8
-#
 # The PDF format has some built-in font support. If you want to use other fonts
 # in Prawn you need to embed the font file.
 #
@@ -12,26 +10,25 @@
 # times, providing the path each time it is used becomes cumbersome. The example
 # on the next page shows a better way to deal with fonts which are used several
 # times in a document.
-#
-require File.expand_path(File.join(File.dirname(__FILE__),
-                                   %w[.. example_helper]))
+
+require_relative '../example_helper'
 
 filename = File.basename(__FILE__).gsub('.rb', '.pdf')
 Prawn::ManualBuilder::Example.generate(filename) do
   # Using a TTF font file
   font("#{Prawn::DATADIR}/fonts/DejaVuSans.ttf") do
-    text "Written with the DejaVu Sans TTF font."
+    text 'Written with the DejaVu Sans TTF font.'
   end
   move_down 20
 
-  text "Written with the default font."
+  text 'Written with the default font.'
   move_down 20
 
   # Using an DFONT font file
   font("#{Prawn::DATADIR}/fonts/Panic+Sans.dfont") do
-    text "Written with the Panic Sans DFONT font"
+    text 'Written with the Panic Sans DFONT font'
   end
   move_down 20
 
-  text "Written with the default font once more."
+  text 'Written with the default font once more.'
 end
